<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gmd="http://www.isotc211.org/2005/gmd" xmlns:gco="http://www.isotc211.org/2005/gco" xmlns:gml="http://www.opengis.net/gml" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:exslt="http://exslt.org/common" xmlns:msxsl="urn:schemas-microsoft-com:xslt" exclude-result-prefixes="exslt msxsl">
   <xsl:output method="html" doctype-public="XSLT-compat" encoding="UTF-8" />

   <msxsl:script language="JScript" implements-prefix="exslt">
      this['node-set'] = function (x) {
      return x;
      }
   </msxsl:script>

   <xsl:template match="gmd:MD_Metadata">

      <html>
         <link rel="stylesheet" type="text/css" href="ISO19115-css.css" />
         <head>
            <title>
               <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:title/gco:CharacterString" />
            </title>
         </head>
         <body>
            <!-- Store in variable so that a second pass can be done to count and number the bands -->
            <xsl:variable name="firstPass">
               <div class="main">
                  <div class="title">
                     <h2>
                        <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:title/gco:CharacterString" />
                     </h2>
                  </div>
                  <div class="section metaDataSection">
                     <table class="infoGroup">
                        <tr>
                           <td>Metadata Standard:</td>
                           <td>
                              <xsl:value-of select="gmd:metadataStandardName/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Version:</td>
                           <td>
                              <xsl:value-of select="gmd:metadataStandardVersion/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Date Stamp:</td>
                           <td>
                              <xsl:call-template name="parseDateTime">
                                 <xsl:with-param name="dateTime" select="gmd:dateStamp/gco:DateTime" />
                              </xsl:call-template>
                           </td>
                        </tr>
                        <xsl:for-each select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:date/gmd:CI_Date">
                           <tr>
                              <td>
                                 <xsl:call-template name="formatTitles">
                                    <xsl:with-param name="text" select="normalize-space(concat(gmd:dateType/gmd:CI_DateTypeCode,' date:'))" />
                                 </xsl:call-template>
                              </td>
                              <td>
                                 <xsl:call-template name="parseDateTime">
                                    <xsl:with-param name="dateTime" select="gmd:date/gco:DateTime" />
                                 </xsl:call-template>
                              </td>
                           </tr>
                        </xsl:for-each>
                        <tr>
                           <td>Raw Filename:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:citation/gmd:CI_Citation/gmd:identifier/gmd:RS_Identifier/gmd:code/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Abstract:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:abstract/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Purpose:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:purpose/gco:CharacterString" />
                           </td>
                        </tr>
                     </table>
                  </div>


                  <div class="infoGroup piSection">
                     <h3>Principal Investigator</h3>
                     <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:individualName/gco:CharacterString" />
                     <h3>File Identifier</h3>
                     <xsl:value-of select="gmd:fileIdentifier/gco:CharacterString" />
                  </div>


                  <div class="infoGroup flightDetailsSection">
                     <h3>Flight Details</h3>
                     <xsl:value-of select="gmd:dataQualityInfo/gmd:DQ_DataQuality/gmd:lineage/gmd:LI_Lineage/gmd:statement/gco:CharacterString" />
                     <table class="infoTable">
                        <tr>
                           <td>Topic Category:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:topicCategory/gmd:MD_TopicCategoryCode" />
                           </td>
                        </tr>
                        <tr>
                           <td>Area:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:description/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Longitude Bounds:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:westBoundLongitude/gco:Decimal" />
                              <xsl:text>, </xsl:text>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:eastBoundLongitude/gco:Decimal" />
                           </td>
                           <td>
                              <br />
                           </td>
                        </tr>
                        <tr>
                           <td>Latitude Bounds:</td>
                           <td>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:southBoundLatitude/gco:Decimal" />
                              <xsl:text>, </xsl:text>
                              <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:northBoundLatitude/gco:Decimal" />
                           </td>
                        </tr>
                        <tr>
                           <td>Flight start time:</td>
                           <td>
                              <xsl:call-template name="parseDateTime">
                                 <xsl:with-param name="dateTime" select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:beginPosition" />
                              </xsl:call-template>
                           </td>
                        </tr>
                        <tr>
                           <td>Flight end time:</td>
                           <td>
                              <xsl:call-template name="parseDateTime">
                                 <xsl:with-param name="dateTime" select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:extent/gmd:EX_Extent/gmd:temporalElement/gmd:EX_TemporalExtent/gmd:extent/gml:TimePeriod/gml:endPosition" />
                              </xsl:call-template>
                           </td>
                        </tr>
                        <tr>
                           <td>
                              <xsl:call-template name="PreserveLineBreaks">
                                 <xsl:with-param name="text" select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:credit/gco:CharacterString" />
                              </xsl:call-template>
                           </td>
                        </tr>
                     </table>
                  </div>
                  <div class="infoGroup contactsSection clearfix">
                     <h3>Contacts</h3>
                     <xsl:for-each select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:pointOfContact/gmd:CI_ResponsibleParty">
                        <xsl:if test="not(contains(gmd:role/gmd:CI_RoleCode, 'principalInvestigator'))">
                           <div class="infoGroup floatTable">
                              <h4>
                                 <xsl:call-template name="formatTitles">
                                    <xsl:with-param name="text" select="gmd:role/gmd:CI_RoleCode" />
                                 </xsl:call-template>
                              </h4>
                              <xsl:value-of select="gmd:organisationName/gco:CharacterString" />
                              <br />
                              <xsl:value-of select="gmd:contactInfo/gmd:CI_Contact/gmd:phone/gmd:CI_Telephone/gmd:voice/gco:CharacterString" />
                              <br />
                              <address>
                                 <xsl:for-each select="gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:deliveryPoint">
                                    <xsl:value-of select="gco:CharacterString" />
                                    <br />
                                 </xsl:for-each>
                                 <xsl:value-of select="gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:city/gco:CharacterString" />
                                 <br />
                                 <xsl:value-of select="gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:administrativeArea/gco:CharacterString" />
                                 <br />
                                 <xsl:value-of select="gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:postalCode/gco:CharacterString" />
                                 <br />
                                 <xsl:value-of select="gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:country/gco:CharacterString" />
                              </address>
                              <xsl:variable name="emailAddress" select="gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:electronicMailAddress/gco:CharacterString" />
                              <a href="mailto:{$emailAddress}">
                                 <xsl:value-of select="$emailAddress" />
                              </a>
                           </div>
                        </xsl:if>
                     </xsl:for-each>
                  </div>



                  <div class="infoGroup dataQualitySection">
                     <h3>Data Quality</h3>
                     <xsl:for-each select="gmd:dataQualityInfo/gmd:DQ_DataQuality/gmd:report/gmd:DQ_DomainConsistency/gmd:result/gmd:DQ_ConformanceResult">
                        <xsl:if test="contains(gmd:specification/gmd:CI_Citation/gmd:title/gco:CharacterString, 'Hyperspectral')">
                           <xsl:value-of select="gmd:specification/gmd:CI_Citation/gmd:title/gco:CharacterString" />
                           <br />
                           <xsl:call-template name="formatTitles">
                              <xsl:with-param name="text" select="normalize-space(concat(gmd:specification/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:dateType,'date:'))" />
                           </xsl:call-template>
                           <xsl:call-template name="parseDateTime">
                              <xsl:with-param name="dateTime" select="gmd:specification/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:date" />
                           </xsl:call-template>
                           <br />
                           <xsl:value-of select="gmd:explanation/gco:CharacterString" />
                           <xsl:text>:</xsl:text>
                           <xsl:value-of select="gmd:pass/gco:Boolean" />
                        </xsl:if>
                     </xsl:for-each>
                  </div>


                  <div class="infoGroup GemetSection">
                     <h3>GEMET Theme</h3>
                     <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:descriptiveKeywords/gmd:MD_Keywords/gmd:thesaurusName/gmd:CI_Citation/gmd:title/gco:CharacterString" />
                     <br />
                     <xsl:call-template name="formatTitles">
                        <xsl:with-param name="text" select="normalize-space(concat(gmd:identificationInfo/gmd:MD_DataIdentification/gmd:descriptiveKeywords/gmd:MD_Keywords/gmd:thesaurusName/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:dateType/gmd:CI_DateTypeCode,'date:'))" />
                     </xsl:call-template>
                     <xsl:text> </xsl:text>
                     <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:descriptiveKeywords/gmd:MD_Keywords/gmd:thesaurusName/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:date/gco:Date" />
                  </div>


                  <div class="infoGroup DistributionSection">
                     <h3>Distribution Information</h3>
                     <table>
                        <tr>
                           <td>Format:</td>
                           <td>
                              <xsl:value-of select="gmd:distributionInfo/gmd:MD_Distribution/gmd:distributionFormat/gmd:MD_Format/gmd:name/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Version:</td>
                           <td>
                              <xsl:value-of select="gmd:distributionInfo/gmd:MD_Distribution/gmd:distributionFormat/gmd:MD_Format/gmd:version/gco:CharacterString" />
                           </td>
                        </tr>
                        <tr>
                           <td>Online Resource:</td>
                           <td>
                              <xsl:value-of select="gmd:distributionInfo/gmd:MD_Distribution/gmd:transferOptions/gmd:MD_DigitalTransferOptions/gmd:onLine/gmd:CI_OnlineResource/gmd:linkage/gmd:URL" />
                           </td>
                        </tr>
                     </table>
                  </div>


                  <!-- Supplemental section -->
                  <xsl:if test="/gmd:MD_Metadata/gmd:identificationInfo/gmd:MD_DataIdentification/gmd:supplementalInformation/gco:CharacterString">
                     <h3>Flightline Details</h3>
                     <xsl:call-template name="splitWallOfText">
                        <xsl:with-param name="text" select="/gmd:MD_Metadata/gmd:identificationInfo/gmd:MD_DataIdentification/gmd:supplementalInformation/gco:CharacterString" />
                     </xsl:call-template>
                     <!-- print the parts of the wall 'o text that are stored as comments instead of being in the main string -->
                     <div class="infoGroup">
                        <table>
                           <h3>Comments:</h3>
                           <xsl:for-each select=".//comment()">
                              <tr>
                                 <td>
                                    <xsl:value-of select="." />
                                 </td>
                              </tr>
                           </xsl:for-each>
                        </table>
                     </div>

                  </xsl:if>
                  <div class="infoGroup processingSection">
                     <h3>Processing</h3>
                     <xsl:for-each select="gmd:dataQualityInfo/gmd:DQ_DataQuality/gmd:lineage/gmd:LI_Lineage/gmd:statement">
                        <xsl:value-of select="gco:CharacterString" />
                        <br />
                     </xsl:for-each>
                     <br />
                     <xsl:for-each select="gmd:dataQualityInfo/gmd:DQ_DataQuality/gmd:lineage/gmd:LI_Lineage/gmd:processStep/gmd:LI_ProcessStep/gmd:description">
                        <xsl:value-of select="gco:CharacterString" />
                        <br />
                        <br />
                     </xsl:for-each>
                  </div>
               </div>
            </xsl:variable>
            <!-- second pass to count and number the bands -->
            <xsl:apply-templates select="exslt:node-set($firstPass)" mode="secondPass" />
         </body>
         <footer>
            <div class="legalSection">
               <xsl:for-each select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:resourceConstraints/gmd:MD_LegalConstraints">

                  <xsl:value-of select="gmd:useLimitation/gco:CharacterString" />
                  <br />
                  <br />
               </xsl:for-each>
               <xsl:value-of select="gmd:identificationInfo/gmd:MD_DataIdentification/gmd:resourceConstraints/gmd:MD_Constraints/gmd:useLimitation/gco:CharacterString" />
            </div>
         </footer>
      </html>
   </xsl:template>



   <!-- second pass to count and number the bands -->
   <xsl:template match="*" mode="secondPass">
      <xsl:copy>
         <xsl:copy-of select="@*" />
         <xsl:apply-templates mode="secondPass" />
      </xsl:copy>
   </xsl:template>

   <xsl:template match="div[contains(@class,'bandTable')]" mode="secondPass">
      <div>
         <xsl:attribute name="class">
            <xsl:value-of select="@class" />
         </xsl:attribute>
         <table>
            <th>
               <xsl:text>Band: </xsl:text>
               <xsl:value-of select="count(preceding-sibling::div)" />
            </th>
            <xsl:copy-of select="current()/*/*" />
         </table>
      </div>
   </xsl:template>

   <xsl:template name="PreserveLineBreaks">
      <xsl:param name="text" />
      <xsl:choose>
         <xsl:when test="contains($text,'&#xA;')">
            <xsl:choose>
               <xsl:when test="':'=substring(substring-before($text,'&#xA;'), string-length(substring-before($text,'&#xA;')) - string-length(':') + 1)">
                  <b>
                     <xsl:call-template name="formatTitles">
                        <xsl:with-param name="text" select="normalize-space(substring-before($text,'&#xA;'))" />
                     </xsl:call-template>
                  </b>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="substring-before($text,'&#xA;')" />
               </xsl:otherwise>
            </xsl:choose>
            <!--xsl:if test="(contains(substring-before($text,'&#xA;'), ''))" -->
            <br />
            <!--/xsl:if -->
            <xsl:if test="contains(substring(substring-after($text,'&#xA;'),1,30),'band:')">
               <br />
            </xsl:if>
            <xsl:call-template name="PreserveLineBreaks">
               <xsl:with-param name="text" select="substring-after($text,'&#xA;')" />
            </xsl:call-template>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="$text" />
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>



   <xsl:template name="TabledLineBreaks">
      <xsl:param name="text" />
      <xsl:choose>
         <xsl:when test="not(boolean($text))">
         </xsl:when>
         <!-- fix for final delimiter showing up in document when delimiting by "band:" -->
         <xsl:when test="$text = 'band:'">
         </xsl:when>

         <!-- split into paragraphs and wrap each of them in a table -->
         <xsl:when test="contains($text,'&#xA;&#xA;')"><!-- string contains more than one paragraph -->
            <div class="infoGroup floatGroup">
               <table>
                  <xsl:call-template name="TabledLineBreaks">
                     <xsl:with-param name="text" select="substring-before($text,'&#xA;&#xA;')" />
                  </xsl:call-template>
               </table>
            </div>
            <!-- recurse and process the remainder of the string. -->
            <xsl:call-template name="TabledLineBreaks">
               <xsl:with-param name="text" select="substring-after($text,'&#xA;&#xA;')" />
            </xsl:call-template>
         </xsl:when>



         <!-- do the same, but using a different check as bands have no empty lines between them. -->
         <xsl:when test="contains(substring-before($text,'&#xA;'),'band:')">
            <div class="infoGroup bandTable">
               <table>
                  <!-- process band section -->
                  <xsl:choose>
                     <xsl:when test="boolean(substring-before(substring-after($text,'&#xA;'),'band:'))">
                        <xsl:call-template name="TabledLineBreaks">
                           <xsl:with-param name="text" select="substring-before(substring-after($text,'&#xA;'),'band:')" />
                        </xsl:call-template>
                     </xsl:when>
                     <xsl:otherwise>
                        <xsl:call-template name="TabledLineBreaks">
                           <xsl:with-param name="text" select="substring-after($text,'&#xA;')" />
                        </xsl:call-template>
                     </xsl:otherwise>
                  </xsl:choose>
               </table>
            </div>
            <!-- process rest of string -->

            <xsl:call-template name="TabledLineBreaks">
               <xsl:with-param name="text" select="concat('band:',substring-after(substring-after($text,'band:'),'band:'))" />
            </xsl:call-template>
         </xsl:when>


         <xsl:otherwise><!-- string is a single paragraph -->
            <xsl:choose>
               <xsl:when test="contains($text,'&#xA;')"><!-- if there are multiple lines -->
                  <!-- check if the following line contains the units -->
                  <xsl:choose>
                     <xsl:when test="contains(substring-before(substring-after($text,'&#xA;'),'&#xA;'),'unit:') or contains(substring-before(substring-after($text,'&#xA;'),'&#xA;'),'units:')">
                        <xsl:variable name="unit" select="substring-before(substring-after(substring-after($text,'&#xA;'),':'),'&#xA;')" />
                        <xsl:call-template name="TabledLineBreaks">
                           <xsl:with-param name="text" select="concat(normalize-space(substring-before($text,'&#xA;')),$unit)" />
                        </xsl:call-template>
                        <!-- recurse and process the remainder of the string. -->
                        <xsl:call-template name="TabledLineBreaks">
                           <xsl:with-param name="text" select="substring-after(substring-after($text,'&#xA;'),'&#xA;')" />
                        </xsl:call-template>
                     </xsl:when>
                     <xsl:otherwise>
                        <!-- Take everything before the first line break and recurse. -->
                        <xsl:call-template name="TabledLineBreaks">
                           <xsl:with-param name="text" select="normalize-space(substring-before($text,'&#xA;'))" />
                        </xsl:call-template>
                        <!-- recurse and process the remainder of the string. -->
                        <xsl:call-template name="TabledLineBreaks">
                           <xsl:with-param name="text" select="substring-after($text,'&#xA;')" />
                        </xsl:call-template>
                     </xsl:otherwise>
                  </xsl:choose>

               </xsl:when>
               <xsl:otherwise><!-- If there is only a single line. -->
                  <xsl:if test="boolean(normalize-space($text))">
                     <xsl:if test="*//comment()">

                        <xsl:value-of disable-output-escaping="yes" select="substring-before(substring-after($text,'&lt;'),'&gt;')" />
                     </xsl:if>
                     <xsl:choose>
                        <!-- This line was a pain to isolate, I haven't been able to find a better way than just checking for it manually. A more general way would save duplicating so much code. -->
                        <xsl:when test="contains($text,'synchronizationProblem:')">
                           <div class="infoGroup floatGroup">
                              <tr>
                                 <td>
                                    <xsl:call-template name="formatTitles">
                                       <xsl:with-param name="text" select="concat(normalize-space(substring-before($text,':')),':')" />
                                    </xsl:call-template>
                                 </td>
                                 <td>
                                    <xsl:call-template name="specifyUnits">
                                       <xsl:with-param name="measurement" select="substring-before($text,':')" />
                                       <xsl:with-param name="value" select="substring-after($text,':')" />
                                       <xsl:with-param name="text" select="substring-after($text,':')" />
                                    </xsl:call-template>
                                 </td>
                              </tr>
                           </div>
                        </xsl:when>
                        <!-- If ":" is at the end of the string, it's a title, so format and print it -->
                        <xsl:when test="contains($text,':') and not(boolean(substring-after($text,':')))">
                           <th colspan="2">
                              <xsl:call-template name="formatTitles">
                                 <xsl:with-param name="text" select="normalize-space($text)" />
                              </xsl:call-template>
                           </th>
                        </xsl:when>
                        <xsl:otherwise><!-- It's a key+value pair -->
                           <tr>
                              <td>
                                 <xsl:call-template name="formatTitles">
                                    <xsl:with-param name="text" select="concat(normalize-space(substring-before($text,':')),':')" />
                                 </xsl:call-template>
                              </td>
                              <td>
                                 <xsl:call-template name="specifyUnits">
                                    <xsl:with-param name="measurement" select="substring-before($text,':')" />
                                    <xsl:with-param name="value" select="substring-after($text,':')" />
                                    <xsl:with-param name="text" select="substring-after($text,':')" />
                                 </xsl:call-template>
                              </td>
                           </tr>
                        </xsl:otherwise>
                     </xsl:choose>
                  </xsl:if>
               </xsl:otherwise>
            </xsl:choose>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>


   <!-- splits the bands list off from the string containing supplimental info. -->
   <xsl:template name="splitWallOfText">
      <xsl:param name="text" />
      <div class="infoGroup supplimentalSection clearfix">
         <xsl:call-template name="TabledLineBreaks">
            <xsl:with-param name="text" select="substring-before($text,'band:')" />
         </xsl:call-template>
      </div>
      <div class="infoGroup bandsSection clearfix">
         <h3>Band details:</h3>
         <br />
         <xsl:call-template name="TabledLineBreaks">
            <xsl:with-param name="text" select="concat('band:',substring-after($text,'band:'))" />
         </xsl:call-template>
      </div>
   </xsl:template>

   <!-- Replaces names with properly spaced and capitalised versions -->
   <xsl:template name="formatTitles">
      <xsl:param name="text" />
      <xsl:choose>
         <xsl:when test="contains($text,'pointOfContact')">
            <xsl:text>Point of contact</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'originator')">
            <xsl:text>Originator</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'sensorSpecifics:')">
            <xsl:text>Sensor specifics:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'type:')">
            <xsl:text>Type:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'pixelsInLine:')">
            <xsl:text>Pixels in line:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'sensorParameters:')">
            <xsl:text>Sensor Parameters:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'radiometricCalibration:')">
            <xsl:text>Radiometric calibration:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'spectralCalibration:')">
            <xsl:text>Spectral calibration:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'aquisitionInfo:')">
            <xsl:text>Aquisition info:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'software:')">
            <xsl:text>Software:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'maximumScanAngle:')">
            <xsl:text>Maximum scan angle:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'numberOfSpectralBands:')">
            <xsl:text>Number of spectral Bands:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'calibrationLaboratory:')">
            <xsl:text>Calibration lab:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'radianceUnits:')">
            <xsl:text>Radiance units:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'scanFrequency:')">
            <xsl:text>Scan Frequency:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'integrationTime:')">
            <xsl:text>Intergration time:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'spectralBinning:')">
            <xsl:text>Spectral binning:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'spatialBinning:')">
            <xsl:text>Spacial binning:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'calibrationFilename:')">
            <xsl:text>Calibration filename:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'dateOfCalibrationFile:')">
            <xsl:text>Date of calibration file:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'navigationUnit:')">
            <xsl:text>Navigation unit:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'pixelSizeX:')">
            <xsl:text>Pixel size X:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'pixelSizeY:')">
            <xsl:text>Pixel size Y:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'dateOfCalibrationFile:')">
            <xsl:text>Date of calibration file:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'altitudeAboveWGS84Ellipsoid:')">
            <xsl:text>Altitude above WGS84 elipsoid:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'angleToTrueNorth:')">
            <xsl:text>Angle to true north:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'planeSpeed:')">
            <xsl:text>Plane speed:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'landCover:')">
            <xsl:text>Land cover:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'softwareDescription:')">
            <br />
            <xsl:text>Type:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'softwareName:')">
            <xsl:text>Name:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'softwareVersion:')">
            <xsl:text>Version:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'synchronizationProblem:')">
            <xsl:text>Synchronisation problem:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'centreWavelength:')">
            <xsl:text>Centre wavelength:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'dem:')">
            <xsl:text>DEM:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'instrument:')">
            <xsl:text>Instrument:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'platform:')">
            <xsl:text>Platform:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'creation date:')">
            <xsl:text>Creation date:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'publication date:')">
            <xsl:text>Publication date:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'filename:')">
            <xsl:text>File name:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'source:')">
            <xsl:text>Source:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'units:')">
            <xsl:text>Units:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'base:')">
            <xsl:text>Base:</xsl:text>
         </xsl:when>
         <xsl:when test="contains($text,'bandwidth:')">
            <xsl:text>Bandwidth:</xsl:text>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="normalize-space($text)" />
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!-- adds units for measurementswhich don't specify them in the xml -->
   <xsl:template name="specifyUnits">
      <xsl:param name="measurement" />
      <xsl:param name="value" />
      <xsl:choose>
         <xsl:when test="contains($measurement,'FOV')">
            <xsl:value-of select="concat($value,'°')" />
         </xsl:when>
         <xsl:when test="contains($measurement,'bandwidth')">
            <xsl:value-of select="concat($value,'')" /><!-- add in the units here once it's known what they are. -->
         </xsl:when>
         <xsl:when test="contains($measurement,'maximumScanAngle')">
            <xsl:value-of select="concat($value,'°')" />
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="$value" />
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <xsl:template name="parseDateTime">
      <xsl:param name="dateTime" />
      <time datetime="{substring($dateTime,0,20)}Z">
         <xsl:choose>
            <xsl:when test="contains($dateTime,'T')">
               <xsl:value-of select="substring-before($dateTime,'T')" />
               <xsl:text>&#160; </xsl:text>
               <xsl:value-of select="substring-after($dateTime,'T')" />
            </xsl:when>
            <xsl:otherwise>
               <xsl:value-of select="$dateTime" />
            </xsl:otherwise>
         </xsl:choose>
      </time>
   </xsl:template>
</xsl:stylesheet>
